@@ -31,7 +31,7 @@ class lines:
 
 	def plot_line(self, X, Y, title, xlabel, ylabel, imgText=None, outpath=None, 
 					subplot=None, xlim=None, ylim=None, xTextShift=0.05, yTextShift=0.95,
-					xTextLoc=None, yTextLoc=None, color='blue', marker='.'):
+					xTextLoc=None, yTextLoc=None, color='blue', marker=',', showImg=True):
 		"""create a default 2D line plot
 		
 		: X: (float) the values for x-axis
@@ -40,6 +40,15 @@ class lines:
 		: yTextShift: (float) Uses the range of y values as total, sets a percentage of place the text
 		: xTextLoc: (float) Uses absolute value and overrides xTextShift
 		: yTextLoc: (float) Uses absolute value and overrides yTextShift
+		: marker types 		".": point		https://www.w3schools.com/python/matplotlib_markers.asp
+							"o": circle
+							",": just a pixel size
+							"s": square
+							"d": dimond
+							"^": triangle
+							"v": upside down triangle
+							"+": plus
+							"x": X
 		:return: None
 		"""
 
@@ -56,7 +65,7 @@ class lines:
 		if ylim is not None: plt.ylim(ylim)
 		
 		if subplot is None:
-			if outpath is None: plt.show()
+			if path is None and showImg: plt.show()
 			else: plt.savefig(outpath)
 
 	def add_text(self, X, Y, textstr, α=0.05, β=0.95, xTextLoc=None, yTextLoc=None):
@@ -84,7 +93,7 @@ class lines:
 	def set_ylabel(self, ylabel, fontsize=16):
 		plt.ylabel(ylabel, fontsize=fontsize)
 
-	def add_plot(self, X,Y, color='blue', marker='.'):
+	def add_plot(self, X,Y, color='blue', marker=','):
 		#color='blue'        # specify color by name
 		#color='g'           # short color code (rgbcmyk)
 		#color='0.75'        # Grayscale between 0 and 1
